@@ -6,7 +6,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 =head1 NAME
 
@@ -95,7 +95,7 @@ use WeakRef;
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 =head1 NAME
 
@@ -294,6 +294,7 @@ sub _get_id {
 sub __get_id {
     my( $self, $ref ) = @_;
     my $class = ref( $ref );
+    die "__get_id requires reference. got '$ref'" unless $class;
     if( $class eq 'Yote::Array') {
         return $ref->[0];
     }
@@ -408,7 +409,7 @@ sub _xform_in {
     if( ref( $val ) ) {
         return $self->_get_id( $val );
     }
-    return "v$val";
+    return defined $val ? "v$val" : undef;
 }
 
 sub _xform_out {
@@ -432,6 +433,12 @@ sub _is_dirty {
     $ans;
 } #_is_dirty
 
+sub _purge {
+    my $self = shift;
+    $self->{_DIRTY} = {};
+    $self->{_WEAK_REFS} = {};
+}
+
 #
 # Returns data structure representing object. References are integers. Values start with 'v'.
 #
@@ -510,7 +517,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 #
 # The string version of the yote object is simply its id. This allows
@@ -524,7 +531,28 @@ use overload
     '!='   => sub { ! ref($_[1]) || $_[1]->{ID} != $_[0]->{ID} },
     fallback => 1;
 
-# add a get()/set() here?
+sub set {
+    my( $self, $fld, $val ) = @_;
+
+    my $inval = $self->{STORE}->_xform_in( $val );
+    $self->{STORE}->_dirty( $self, $self->{ID} ) if $self->{DATA}{$fld} ne $inval;
+    $self->{DATA}{$fld} = $inval;
+    return $self->{STORE}->_xform_out( $self->{DATA}{$fld} );
+}
+sub get {
+    my( $self, $fld, $default ) = @_;
+    my $cur = $self->{DATA}{$fld};
+    if( ! defined( $cur ) && defined( $default ) ) {
+        if( ref( $default ) ) {
+            # this must be done to make sure the reference is saved for cases where the reference has not yet made it to the store of tihngs to save
+            $self->{STORE}->_dirty( $default->{STORE}->_get_id( $default ) );
+        }
+                $self->{STORE}->_dirty( $self, $self->{ID} );
+        $self->{DATA}{$fld} = $self->{STORE}->_xform_in( $default );
+    }
+    return $self->{STORE}->_xform_out( $self->{DATA}{$fld} );
+}
+
 
 # -----------------------
 #
@@ -627,6 +655,7 @@ sub AUTOLOAD {
             my( $self, $init_val ) = @_;
             if( ! defined( $self->{DATA}{$fld} ) && defined($init_val) ) {
                 if( ref( $init_val ) ) {
+                    # this must be done to make sure the reference is saved for cases where the reference has not yet made it to the store of tihngs to save
                     $self->{STORE}->_dirty( $init_val, $self->{STORE}->_get_id( $init_val ) );
                 }
                 $self->{STORE}->_dirty( $self, $self->{ID} );
@@ -719,7 +748,7 @@ use Tie::Array;
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 sub TIEARRAY {
     my( $class, $obj_store, $id, @list ) = @_;
@@ -812,7 +841,7 @@ use Tie::Hash;
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 sub TIEHASH {
     my( $class, $obj_store, $id, %hash ) = @_;
@@ -885,7 +914,7 @@ use constant {
 
 use vars qw($VERSION);
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 #
 # This the main index and stores in which table and position
@@ -1069,6 +1098,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.2  (November 2, 2015))
+       Version 1.3  (Mar 9, 2016))
 
 =cut
